@@ -11,7 +11,7 @@ from .algorithm import Algorithm
 from .model import LinearNet, PackedSet, BetterEmbedding, SplineEmbedding, copy_network, reset_network
 from .data_tensor import DataTensor
 from .optim import BeamOptimizer, BeamScheduler
-from .ssl import BeamSimilarity, Similarities, BeamSSL, BYOL, BeamVICReg, BarlowTwins, VICReg, SimCLR, SimSiam
-from .server import BeamServer, BeamClient
+# from .ssl import BeamSimilarity, Similarities, BeamSSL, BYOL, BeamVICReg, BarlowTwins, VICReg, SimCLR, SimSiam
+# from .server import BeamServer, BeamClient
 
 from ._version import __version__
\ No newline at end of file
